import * as d3 from 'd3';

function renderData(dataElements) {
    let width = 700;
    let height = 500;

    let lat = dataElements.map((o) => +o.lat);
    let long = dataElements.map((o) => +o.long);

    let city = new Set(
        dataElements.map((o) => o.city)
    );
    let data = dataElements.map((o) => ({
        lat: +o.lat,
        long: +o.long,
        dock_count: +o.dock_count,
        city: o.city,
    }));

    let margin = { top: 50, right: 25, bottom: 40, left: 80 };

    const color = d3.scaleOrdinal()
        .domain(city)
        .range(d3.schemeTableau10);

    let x = d3
        .scaleLinear()
        .domain(d3.extent(long))
        .nice()
        .range([margin.left, width - margin.right]);

    let y = d3
        .scaleLinear()
        .domain(d3.extent(lat))
        .nice()
        .range([height - margin.bottom, margin.top]);

    let xAxis = (g) => g
        .attr(
            'transform',
            `translate(0,${height - margin.bottom})`
        )
        .call(d3.axisBottom(x));

    let yAxis = (g) => g
        .attr(
            'transform',
            `translate(${margin.left},0)`
        )
        .call(d3.axisLeft(y));

    const svg = d3.select('body')
        .append('svg')
        .attr('width', width)
        .attr('height', height);

    // legend
    let legend = d3.legendColor()
        .scale(color)
        .shape('path', d3.symbol().type(d3.symbolCircle).size(150)())
        .title('Location');

    svg.append('g')
        .attr('class', 'legend')
        .attr('transform', `translate(${width - 150}, ${margin.top + 30})`);

    svg.append('g')
        .call(xAxis);

    svg.append('g')
        .call(yAxis);

    svg.select('.legend')
        .style('font-size', '13px')
        .call(legend);

    console.log(data);
    svg.append('g')
        .selectAll('circle')
        .data(data)
        .join('circle')
        .attr('fill', d => { return color(d.city); })
        .attr('cx', d => x(d.long))
        .attr('cy', d => y(d.lat))
        .attr('r', 3);

    svg.append('text')
        .attr('fill', 'black')
        .attr('x', width - 350)
        .attr('y', height - 3)
        .style('font-size', '14px')
        .text('Longitude');

    svg.append('text')
        .attr('fill', 'black')
        .attr('x', '150')
        .attr('y', '-10')
        .attr(
            'transform',
            'translate(30, 400) rotate(270)'
        )
        .style('font-size', '14px')
        .text('Latitude');

    svg.append('text')
        .attr('fill', 'black')
        .attr('x', width - 450)
        .attr('y', '20')
        .style('font-size', '18px')
        .text('Bike Stations in Bay Area.');

    svg.append('text')
        .attr('fill', 'black')
        .attr('x', width - 450)
        .attr('y', '35')
        .style('font-size', '12px')
        .text('2013 year.');
}

d3.csv(
    'https://gist.githubusercontent.com/olga-kondr/64dc8df90513ada23e183cbb9fa1f9d4/raw/a69aa9c03948a74bb7453bdbcc7a3c70d81d9d9e/weather.csv'
).then((data) => renderData(data));